==> apache-artemis-2.34.0-source-release.zip: apache-artemis-2.34.0/tests/db-tests/src/test/java/org/apache/activemq/artemis/tests/db/invalid/JdbcStartupInvalidTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.tests.db.invalid;

import java.lang.invoke.MethodHandles;
import java.util.concurrent.TimeUnit;

import org.apache.activemq.artemis.tests.db.common.DBTestBase;
import org.junit.Assert;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class JdbcStartupInvalidTest extends DBTestBase {

   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());

   protected static final String SERVER_NAME = "jdbc-bad-driver";

   @Test
   public void startupBadJdbcConnectionTest() throws Exception {

      Process p = startServer(SERVER_NAME, 0, 0);
      try {
         p.waitFor(20, TimeUnit.SECONDS);
         Assert.assertFalse(p.isAlive());
      } catch (Exception e) {
         logger.warn(e.getMessage(), e);
         Assert.fail(e.getMessage());
      }
   }
}

==> apache-artemis-2.44.0-source-release.zip: apache-artemis-2.44.0/tests/db-tests/src/test/java/org/apache/activemq/artemis/tests/db/invalid/JdbcStartupInvalidTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.tests.db.invalid;

import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.fail;

import java.lang.invoke.MethodHandles;
import java.util.concurrent.TimeUnit;

import org.apache.activemq.artemis.tests.db.common.DBTestBase;
import org.junit.jupiter.api.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class JdbcStartupInvalidTest extends DBTestBase {

   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());

   protected static final String SERVER_NAME = "jdbc-bad-driver";

   @Test
   public void startupBadJdbcConnectionTest() throws Exception {

      Process p = startServer(SERVER_NAME, 0, 0);
      try {
         p.waitFor(20, TimeUnit.SECONDS);
         assertFalse(p.isAlive());
      } catch (Exception e) {
         logger.warn(e.getMessage(), e);
         fail(e.getMessage());
      }
   }
}
